@@ -39,7 +39,7 @@ pwgen-xkcd.pl - Generate a xkcd-style password
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 USAGE
 
@@ -48,7 +48,7 @@ version 1.000
   Options:
     --words      Number of words to generate, default 4
     --digits     Add some digits, default 0
-    --langauge   Language of word list, default en-GB
+    --language   Language of word list, default en-GB
 
 =head1 SEE ALSO
 
