@@ -2,9 +2,9 @@ package CtrlO::Crypt::XkcdPassword;
 use strict;
 use warnings;
 
-# ABSTRACT: Yet another XKCD style password generator
+# ABSTRACT: Yet another xkcd style password generator
 
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 use Carp qw(croak);
 use Crypt::Rijndael;
@@ -137,11 +137,11 @@ __END__
 
 =head1 NAME
 
-CtrlO::Crypt::XkcdPassword - Yet another XKCD style password generator
+CtrlO::Crypt::XkcdPassword - Yet another xkcd style password generator
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -175,12 +175,13 @@ version 1.000
 C<CtrlO::Crypt::XkcdPassword> generates a random password using the
 algorithm suggested in L<https://xkcd.com/936/>: It selects 4 words
 from a curated list of words and combines them into a hopefully easy
-to remember password.
+to remember password (actually a passphrase, but we're all trying to
+getting things done, so who cares..).
 
 But L<https://xkcd.com/927/> also applies to this module, as there are
-already a lot of modules on CPAN also implementing
+already a lot of modules on CPAN implementing
 L<https://xkcd.com/936/>. We still wrote a new one, mainly because we
-wanted to use a strong source of entropy.
+wanted to use a strong source of entropy and a fine-tuned word list.
 
 =head1 METHODS
 
@@ -190,7 +191,7 @@ wanted to use a strong source of entropy.
 
 Initialize a new object. Uses C<CtrlO::Crypt::XkcdPassword::Wordlist::en_gb>
 as a word list per default. The default entropy is based on
-C<Crypt::URandom>, i.e. '/dev/urandom' and should be random enough (at
+C<Crypt::URandom>, i.e. C</dev/urandom> and should be random enough (at
 least more random than plain old C<rand()>).
 
 If you want / need to supply another source of entropy, you can do so
@@ -235,8 +236,7 @@ See L<Defining custom word lists> for more info
   my $pw = $pw_generator->xkcd( words  => 3 );
   my $pw = $pw_generator->xkcd( digits => 2 );
 
-Generate a random, XKCD-style password (actually a passphrase, but
-we're all trying to getting things done, so who cares..)
+Generate a random, xkcd-style password.
 
 Per default will return 4 randomly chosen words from the word list,
 each word's first letter turned to upper case, and concatenated
@@ -255,15 +255,15 @@ C<digits> digits to the password:
   $pw_generator->xkcd( words => 3, digits => 2 );
   # StapleBatteryCorrect75
 
-=head1 Defining custom word lists
+=head1 DEFINING CUSTOM WORD LISTS
 
 Please note that C<language> is only supported for the word lists
-included with this distribution.
+included in this distribution.
 
 =head2 in a plain file
 
 Put your word list into a plain file, one line per word. Install this
-file somewhere on your system. You can now use this word list like
+file somewhere on your system. You can now use your word list like
 this:
 
   CtrlO::Crypt::XkcdPassword->new(
@@ -272,7 +272,7 @@ this:
 
 =head2 in a Perl module using the Wordlist API
 
-Perlancar came up with a unified API for various word list modules,
+L<Perlancar|https://metacpan.org/author/PERLANCAR> came up with a unified API for various word list modules,
 implemented in L<Wordlist|https://metacpan.org/pod/WordList>. Pack
 your list into a module adhering to this API, install the module, and
 load your word list:
@@ -281,7 +281,7 @@ load your word list:
     wordlist => 'Your::Cool::Wordlist'
   );
 
-You can check out L<CtrlO::Crypt::XkcdPassword::Wordlist> (included in
+You can check out L<CtrlO::Crypt::XkcdPassword::Wordlist::en_GB> (included in
 this distribution) for an example. But it's really quite simple: Just
 subclass C<Wordlist> and put your list of words into the C<__DATA__>
 section of the module, one line per word.
@@ -303,7 +303,7 @@ To create a module using the L<Crypt::Diceware> wordlist API, just
 create a package containing a public array C<@Words> containing your
 word list.
 
-=head1 pwgen-xkcd.pl
+=head1 WRAPPER SCRIPT
 
 This distributions includes a simple wrapper script, L<pwgen-xkcd.pl>.
 
@@ -347,7 +347,7 @@ L<Data::Entropy>, which provides good entropy while still being portable.
 
 While L<Crypt::Diceware> has good entropy, we did not like its word
 lists. Of course we could have just provided a word list better suited
-to our needs, but we wanted it to be very easy to generate XKCD-Style
+to our needs, but we wanted it to be very easy to generate xkcd-Style
 passwords
 
 =item * Easy API
